@@ -1,4 +1,5 @@
 from __future__ import absolute_import, unicode_literals
+from re import L
 import sys
 import functools
 import json
@@ -26,9 +27,9 @@ class TextOutput(base.BaseOutput):
         self.color = color
 
     def _get_score_format(self, score):
-        if score < 0.15:
+        if score < 0.3:
             return self._white
-        elif score < 0.4:
+        elif score < 0.7:
             return self._yellow
         else:
             return self._red
@@ -124,12 +125,27 @@ class TextOutput(base.BaseOutput):
     def hunt(self, result, write=True):
         output = []
         output.append(self._blue('Hunt Id: {}'.format(result.id)))
+        output.append(self._white('Status: {}'.format(result.status)))
+        if result.progress is not None:
+            output.append(self._white('Progress: {:.2f}%'.format(result.progress)))
         if result.active is not None:
             output.append(self._white('Active: {}'.format(result.active)))
+        output.append(self._white('Created at: {}'.format(result.created)))
+        if result.summary:
+            output.append(self._white('Total count: {}'.format(result.summary['count'])))
+            self._open_group()
+            for rule, data in result.summary.get('rule', []).items():
+                output.append(self._white('{}: {}'.format(rule, data['count'])))
+            self._close_group()
+        if result.results_csv_uri:
+            output.append(self._white('Download Results CSV:'))
+            self._open_group()
+            output.append(self._white(result.results_csv_uri))
+            self._close_group()
         if result.ruleset_name is not None:
             output.append(self._white('Ruleset Name: {}'.format(result.ruleset_name)))
-        output.append(self._white('Created at: {}'.format(result.created)))
-
+        if result.yara:
+            output.append(self._white('Ruleset Contents:\n{}'.format(result.yara)))
         return self._output(output, write)
 
     def hunt_deletion(self, result, write=True):
@@ -139,23 +155,74 @@ class TextOutput(base.BaseOutput):
 
         return self._output(output, write)
 
-    def hunt_result(self, result, write=True):
+    def historical_result(self, result, write=True):
         output = []
-        output.append(self._white('Match on rule {name}'.format(name=result.rule_name) +
-                                  (', tags: {result_tags}'.format(
-                                     result_tags=result.tags) if result.tags != '' else '')))
-        output.extend(self.artifact_instance(result.artifact, write=False))
+        output.append(self._blue('Id: {}'.format(result.id)))
+        output.append(self._blue('Instance Id: {}'.format(result.instance_id)))
+        output.append(self._white('Created at: {}'.format(result.created)))
+        output.append(self._white('SHA256: {}'.format(result.sha256)))
+        output.append(self._white('Rule: {}'.format(result.rule_name)))
+        if result.malware_family:
+            output.append(self._red('Malware Family: {result_tags}'.format(result_tags=result.malware_family)))
+        if result.polyscore is not None:
+            formatter = self._get_score_format(result.polyscore)
+            output.append(formatter('PolyScore: {:.20f}'.format(result.polyscore)))
+        if result.detections:
+            if result.detections['total'] == 0:
+                output.append(self._white('Detections: No engines responded to this scan. You can trigger a rescan now.'))
+            else:
+                malicious = 'Detections: {}/{} engines reported malicious'\
+                    .format(result.detections['malicious'], result.detections['total'])
+                if result.detections['malicious'] > 0:
+                    output.append(self._red(malicious))
+                else:
+                    output.append(self._white(malicious))
+        if result.tags:
+            output.append(self._white('Tags: {result_tags}'.format(result_tags=result.tags)))
+        if result.download_url:
+            output.append(self._white('Download Url: {result_tags}'.format(result_tags=result.download_url)))
+        return self._output(output, write)
+
+    def live_result(self, result, write=True):
+        output = []
+        output.append(self._blue('Id: {}'.format(result.id)))
+        output.append(self._blue('Instance Id: {}'.format(result.instance_id)))
+        output.append(self._white('Created at: {}'.format(result.created)))
+        output.append(self._white('SHA256: {}'.format(result.sha256)))
+        output.append(self._white('Rule: {}'.format(result.rule_name)))
+        if result.malware_family:
+            output.append(self._red('Malware Family: {result_tags}'.format(result_tags=result.malware_family)))
+        if result.polyscore is not None:
+            formatter = self._get_score_format(result.polyscore)
+            output.append(formatter('PolyScore: {:.20f}'.format(result.polyscore)))
+        if result.detections:
+            if result.detections['total'] == 0:
+                output.append(self._white('Detections: No engines responded to this scan. You can trigger a rescan now.'))
+            else:
+                malicious = 'Detections: {}/{} engines reported malicious'\
+                    .format(result.detections['malicious'], result.detections['total'])
+                if result.detections['malicious'] > 0:
+                    output.append(self._red(malicious))
+                else:
+                    output.append(self._white(malicious))
+        if result.tags:
+            output.append(self._white('Tags: {result_tags}'.format(result_tags=result.tags)))
+        if result.download_url:
+            output.append(self._white('Download Url: {result_tags}'.format(result_tags=result.download_url)))
         return self._output(output, write)
 
     def ruleset(self, result, write=True, contents=False):
         output = []
         output.append(self._blue('Ruleset Id: {}'.format(result.id)))
+        if result.livescan_id:
+            output.append(self._yellow('Live Hunt Id: {}'.format(result.livescan_id)))
+            output.append(self._white('Live Hunt Created at: {}'.format(result.livescan_created)))
         output.append(self._white('Name: {}'.format(result.name)))
         output.append(self._white('Description: {}'.format(result.description)))
         output.append(self._white('Created at: {}'.format(result.created)))
         output.append(self._white('Modified at: {}'.format(result.modified)))
         if contents:
-            output.append(self._white('Contents:\n{}'.format(result.yara)))
+            output.append(self._white('Ruleset Contents:\n{}'.format(result.yara)))
         return self._output(output, write)
 
     def tag_link(self, result, write=True):
@@ -201,6 +268,36 @@ class TextOutput(base.BaseOutput):
         self._dfs_mapping_render(output, [], mapping.json)
         return self._output(output, write)
 
+    def iocs(self, iocs, write=True):
+        output = []
+        output.append(self._white('============================= IOCs ============================='))
+        for result in iocs:
+            data = result.json
+            if type(data) is dict:
+                output.append(self._white('ImpHash: {}'.format(data['imphash'])))
+                output.append(self._white('IPs: {}'.format(", ".join(data['ips']))))
+                output.append(self._white('URLs: {}'.format(", ".join(data['urls']))))
+                output.append(self._white('TTPs: {}'.format(", ".join(data['ttps']))))
+            else:
+                output.append(self._white('SHA256: {}'.format(data)))
+        return self._output(output, write)
+    
+    def known_host(self, ioc_known, write=True):
+        output = []
+        output.append(self._white('============================= Known IOC ============================='))
+        output.append(self._white('ID: {}'.format(ioc_known.json['id'])))
+        output.append(self._white('type: {}'.format(ioc_known.json['type'])))
+        output.append(self._white('host: {}'.format(ioc_known.json['host'])))
+        output.append(self._white('source: {}'.format(ioc_known.json['source'])))
+        output.append(self._white('good: {}'.format(ioc_known.json['good'])))
+        return self._output(output, write)
+
+    def sandbox_result(self, result, write=True):
+        output = []
+        output.append(self._white('============================= Sandbox result ============================='))
+        output.append(self._white('result: {}'.format(result.json['status'])))
+        return self._output(output, write)
+
     def metadata(self, instance, write=True):
         output = []
         output.append(self._white('============================= Metadata ============================='))
@@ -271,6 +368,8 @@ class TextOutput(base.BaseOutput):
         output.append(self._blue('Assertions Job id: {}'.format(instance.id)))
         output.append(self._white('Engine id: {}'.format(instance.engine_id)))
         output.append(self._white('Created at: {}'.format(instance.created)))
+        output.append(self._white('Start date: {}'.format(instance.date_start)))
+        output.append(self._white('End date: {}'.format(instance.date_end)))
 
         if instance.storage_path is not None:
             output.append(self._white('Download: {}'.format(instance.storage_path)))
@@ -290,6 +389,8 @@ class TextOutput(base.BaseOutput):
         output.append(self._blue('Votes Job id: {}'.format(instance.id)))
         output.append(self._white('Engine id: {}'.format(instance.engine_id)))
         output.append(self._white('Created at: {}'.format(instance.created)))
+        output.append(self._white('Start date: {}'.format(instance.date_start)))
+        output.append(self._white('End date: {}'.format(instance.date_end)))
 
         if instance.storage_path is not None:
             output.append(self._white('Download: {}'.format(instance.storage_path)))
